@@ -2,6 +2,6 @@
 rbeta1 <- function(n, a) {
   if (a != 1 ) {
     x <- exp( -rexp(n, a) )
-  } else x <- runif(n)
+  } else x <- Rfast2::Runif(n)
   x   
 }
\ No newline at end of file
