@@ -2,10 +2,11 @@
 #include <R_ext/Rdynload.h>
 
 // Manos
-
+SEXP Rfast2_bessel(SEXP, SEXP, SEXP, SEXP);
 SEXP Rfast2_benchmark(SEXP, SEXP, SEXP, SEXP);
 SEXP Rfast2_col_group(SEXP, SEXP, SEXP, SEXP);
 SEXP Rfast2_colQuantile(SEXP, SEXP, SEXP, SEXP);
+SEXP Rfast2_kernel(SEXP, SEXP,SEXP, SEXP);
 SEXP Rfast2_is_upper_tri(SEXP, SEXP);
 SEXP Rfast2_is_lower_tri(SEXP, SEXP);
 SEXP Rfast2_is_skew_symmetric(SEXP);
@@ -17,6 +18,13 @@ SEXP Rfast2_rowQuantile(SEXP, SEXP, SEXP, SEXP);
 SEXP Rfast2_colTrimMean(SEXP, SEXP, SEXP, SEXP);
 SEXP Rfast2_rowTrimMean(SEXP, SEXP, SEXP, SEXP);
 SEXP Rfast2_Runif(SEXP, SEXP, SEXP);
+SEXP Rfast2_Rcauchy(SEXP, SEXP, SEXP);
+SEXP Rfast2_Rgeom(SEXP, SEXP);
+SEXP Rfast2_Rbeta(SEXP, SEXP, SEXP);
+SEXP Rfast2_Rexp(SEXP, SEXP);
+SEXP Rfast2_Rchisq(SEXP, SEXP);
+SEXP Rfast2_Rgamma(SEXP, SEXP, SEXP);
+SEXP Rfast2_Rt(SEXP, SEXP, SEXP);
 SEXP Rfast2_Sample_int(SEXP, SEXP, SEXP);
 SEXP Rfast2_Sample(SEXP, SEXP, SEXP);
 SEXP Rfast2_trimmean(SEXP, SEXP, SEXP);
@@ -37,7 +45,6 @@ SEXP Rfast2_colspml_mle(SEXP, SEXP, SEXP, SEXP);
 SEXP Rfast2_colcauchy_mle(SEXP, SEXP, SEXP, SEXP);
 SEXP Rfast2_colbeta_mle(SEXP, SEXP, SEXP, SEXP);
 SEXP Rfast2_censweib_reg(SEXP, SEXP, SEXP, SEXP, SEXP);
-// SEXP Rfast2_frechet2_c(SEXP , SEXP , SEXP , SEXP k1SEXP);
 SEXP Rfast2_fbed_reg(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 SEXP Rfast2_fedhc_skeleton(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 SEXP Rfast2_multinom_reg(SEXP, SEXP, SEXP, SEXP);
@@ -60,10 +67,12 @@ SEXP Rfast2_colcenspois_mle(SEXP, SEXP, SEXP, SEXP);
 SEXP Rfast2_censpois_mle(SEXP, SEXP);
 SEXP Rfast2_colcensweibull_mle(SEXP, SEXP, SEXP, SEXP, SEXP);
 SEXP Rfast2_censweibull_mle(SEXP, SEXP, SEXP);
+SEXP Rfast2_frechet_nn(SEXP , SEXP , SEXP , SEXP , SEXP , SEXP);
 
 // Lasithiotakis
 
 static const R_CallMethodDef CallEntries[] = {
+    {"Rfast2_bessel", (DL_FUNC)&Rfast2_bessel, 4},
     {"Rfast2_benchmark", (DL_FUNC)&Rfast2_benchmark, 4},
     {"Rfast2_col_group", (DL_FUNC)&Rfast2_col_group, 4},
     {"Rfast2_colQuantile", (DL_FUNC)&Rfast2_colQuantile, 4},
@@ -77,7 +86,15 @@ static const R_CallMethodDef CallEntries[] = {
     {"Rfast2_rowQuantile", (DL_FUNC)&Rfast2_rowQuantile, 4},
     {"Rfast2_rowTrimMean", (DL_FUNC)&Rfast2_rowTrimMean, 4},
     {"Rfast2_colTrimMean", (DL_FUNC)&Rfast2_colTrimMean, 4},
+	  {"Rfast2_kernel", (DL_FUNC)&Rfast2_kernel, 4},
     {"Rfast2_Runif", (DL_FUNC)&Rfast2_Runif, 3},
+    {"Rfast2_Rbeta", (DL_FUNC)&Rfast2_Rbeta, 3},
+    {"Rfast2_Rexp", (DL_FUNC)&Rfast2_Rexp, 2},
+    {"Rfast2_Rchisq", (DL_FUNC)&Rfast2_Rchisq, 2},
+    {"Rfast2_Rgeom", (DL_FUNC)&Rfast2_Rgeom, 2},
+    {"Rfast2_Rcauchy", (DL_FUNC)&Rfast2_Rcauchy, 3},
+    {"Rfast2_Rgamma", (DL_FUNC)&Rfast2_Rgamma, 3},
+    {"Rfast2_Rt", (DL_FUNC)&Rfast2_Rt, 3},
     {"Rfast2_Sample_int", (DL_FUNC)&Rfast2_Sample_int, 3},
     {"Rfast2_Sample", (DL_FUNC)&Rfast2_Sample, 3},
     {"Rfast2_trimmean", (DL_FUNC)&Rfast2_trimmean, 3},
@@ -108,6 +125,7 @@ static const R_CallMethodDef CallEntries[] = {
     {"Rfast2_censpois_mle", (DL_FUNC)&Rfast2_censpois_mle, 2},
     {"Rfast2_colcensweibull_mle", (DL_FUNC)&Rfast2_colcensweibull_mle, 5},
     {"Rfast2_censweibull_mle", (DL_FUNC)&Rfast2_censweibull_mle, 3},
+    {"Rfast2_frechet_nn", (DL_FUNC)&Rfast2_frechet_nn, 6},
     {NULL, NULL, 0}};
 
 void R_init_Rfast2(DllInfo *info)
